@@ -1,6 +1,6 @@
 """Hunspellcheck package."""
 
-from hunspellcheck.cli import extend_argument_parser
+from hunspellcheck.cli import hunspellchecker_argument_parser
 from hunspellcheck.exceptions import InvalidLanguageDictionaryError
 from hunspellcheck.hunspell.dictionaries import (
     assert_is_valid_dictionary_language_or_filename,
@@ -19,12 +19,12 @@ from hunspellcheck.spellchecker import (
 )
 
 
-__version__ = "0.0.3"
+__version__ = "0.0.5"
 __title__ = "hunspellcheck"
 __all__ = (
     "HunspellChecker",
     "InvalidLanguageDictionaryError",
-    "extend_argument_parser",
+    "hunspellchecker_argument_parser",
     "gen_available_dictionaries",
     "gen_available_dictionaries_with_langcodes",
     "get_hunspell_version",
